|package-version|
|python-versions|
|Documentation Status|

Pymox is an open source mock object framework for Python.

First Steps
-----------

`Installation <http://pymox.readthedocs.io/en/latest/install.html>`__
`Tutorial <http://pymox.readthedocs.io/en/latest/tutorial.html>`__

Documentation
-------------

http://pymox.readthedocs.io/en/latest/index.html

Community
---------

User and developer discussion group:

http://groups.google.com/group/mox-discuss

Disclaimer
----------

Pymox is a fork of Mox. Mox is Copyright 2008 Google Inc, and licensed
under the Apache License, Version 2.0; see the file COPYING for details.
If you would like to help us improve Mox, join the group.

.. |package-version| image:: https://badge.fury.io/py/pymox.svg
.. |python-versions| image:: https://img.shields.io/pypi/pyversions/pymox.svg
.. |Documentation Status| image:: https://readthedocs.org/projects/pymox/badge/?version=latest
   :target: http://pymox.readthedocs.io/en/latest/?badge=latest
